<template>
	<HMContainer type="card">
		<template #header>
			<el-form ref="queryFormRef" :inline="true" :model="queryParams">
				<el-form-item label="标题" prop="title">
					<el-input v-model="queryParams.title" style="width: 226.4px" placeholder="标题" clearable />
				</el-form-item>

				<el-form-item>
					<el-button type="primary" icon="ele-Search" @click="handleQueryTable"> 查询 </el-button>
					<el-button icon="ele-Refresh" @click="resetQuery">重置 </el-button>
					<!-- <el-button icon="ele-Plus" @click="openOptDlg()"> 添加 </el-button> -->
				</el-form-item>
			</el-form>
		</template>
		<template #main>
			<div class="h-full" ref="chatDragContainerRef">
				<el-table
					v-loading="tableLoading"
					ref="draggableTableRef"
					class="h100"
					border
					:row-class-name="isDragStatus ? 'cursor-move' : 'cursor-pointer'"
					:data="displayTableData"
					highlight-current-row
				>
					<el-table-column type="index" label="序号" width="55" fixed="left" align="center"></el-table-column>
					<el-table-column prop="title" label="名称" fixed="left" show-overflow-tooltip> </el-table-column>
					<el-table-column label="数据库类型" prop="db_type" width="100" show-overflow-tooltip> </el-table-column>

					<el-table-column label="类型" prop="type" width="100" show-overflow-tooltip> </el-table-column>

					<el-table-column label="操作" width="200" fixed="right" show-overflow-tooltip>
						<template #default="scope">
							<div class="space-x-3 items-center flex">
								<!-- <el-tooltip effect="dark" content="编辑" placement="top">
									<i class="ywifont ywicon-bianji !text-[15px] text-blue-400 cursor-pointer" @click="openOptDlg(scope.row)"></i>
								</el-tooltip> -->
								<el-tooltip effect="dark" content="数据源配置" placement="top">
									<i class="ywifont ywicon-shujuguanli !text-[16px] text-blue-400 cursor-pointer" @click="openDataSourceConfigDlg(scope.row)"></i>
								</el-tooltip>
								<!-- <el-tooltip effect="dark" content="删除" placement="top">
									<i
										class="ywifont ywicon-shanchu !text-[17px] text-red-400 cursor-pointer"
										@click="
											() => {
												deleteCurrentRow(scope.row, '页面', metricApi.deleteSupervisor, () => {
													const foundIndex = tableData.findIndex((item) => item === scope.row);
													foundIndex > -1 && tableData.splice(foundIndex, 1);
												});
											}
										"
									></i>
								</el-tooltip> -->
							</div>
						</template>
					</el-table-column>
				</el-table>
			</div>
		</template>

		<!-- <OptDlg v-model="optDlgIsShow" :item="optDlgMapRow" @insert="insertOpt" @update="updateOpt" :groupId="currentListID"></OptDlg> -->
		<!-- <MetricPrompt v-model="infoDlgIsShow" :metricItem="infoDlgMapRow"></MetricPrompt>
		<MetricName v-model="metricNameIsShow" :metricItem="metricNameMapRow"></MetricName> -->
		<DataSourceConfigDlg v-model="dataSourceConfigDlgIsShow" :item="dataSourceConfigDlgMapRow"></DataSourceConfigDlg>
	</HMContainer>
</template>

<script setup lang="ts">
import { onMounted, ref } from 'vue';
import { usePageDisplay } from '/@/hooks/usePageDisplay';
import { useQueryTable } from '/@/hooks/useQueryTable';
// import { useTableSort } from '/@/hooks/useTableSort';
// import { useValidateUniqueness } from '/@/hooks/useValidateUniqueness';
import { ElMessage } from 'element-plus';
import * as dataSourceApi from '/@/api/dataSource';
import { updatePublishStatus } from '/@/api/supervisorAdmin';
import DataSourceConfigDlg from './components/DataSourceConfigDlg.vue';
import { SupervisorPublished } from '../../lowCode/sqlAmis/types';
import HMContainer from '/@/components/layout/HMContainer.vue';

//#region ====================== 表格数据，table init ======================
const tableLoading = ref(false);
const tableData = ref([]);
const isDragStatus = ref(false);
const getTableData = async () => {
	const res = await dataSourceApi.getDataSourceList();

	tableData.value = res?.values ?? [];
};
//#endregion

//#region ====================== 表格查询、排序，search form init ======================

const queryParams = ref({
	title: '',
});
const { resetQuery, handleQueryTable, displayTableData } = useQueryTable(tableData, queryParams, () => {
	displayTableData.value = tableData.value;
});

//#endregion

//#region ====================== 查询快捷键 ======================
const queryFormRef = ref(null);
const pressEnterSearch = (ev: KeyboardEvent) => {
	if (ev.key === 'Enter') {
		handleQueryTable();
	}
};
usePageDisplay(
	() => {
		queryFormRef.value?.$el?.addEventListener('keypress', pressEnterSearch);
	},
	() => {
		queryFormRef.value?.$el?.removeEventListener('keypress', pressEnterSearch);
	}
);
//#endregion

//#region ====================== 添加修改操作 ======================
const optDlgIsShow = ref(false);
const optDlgMapRow = ref(null);
const openOptDlg = (row?: any) => {
	optDlgMapRow.value = row;
	optDlgIsShow.value = true;
};

const updateOpt = (formValue) => {
	const foundIndex = tableData.value.findIndex((item) => item.id === formValue.id);
	if (foundIndex > -1) {
		tableData.value[foundIndex] = {
			...tableData.value[foundIndex],
			...formValue,
		};
	}
};

const insertOpt = (newData) => {
	tableData.value.unshift({ ...newData, published: SupervisorPublished.N });
};
//#endregion

const updatePublishedById = (id: string, published: SupervisorPublished) => {
	const row = tableData.value.find((item) => item.id === id);
	if (row) {
		row.published = published;
	}
};
//#region ====================== 改变发布状态 ======================
const publishStatusChange = async (published: SupervisorPublished, id, index) => {
	const res = await updatePublishStatus(
		{
			id: id,
			publish: published,
		},
		{
			loading: false,
		}
	);
	const origin = published === SupervisorPublished.Y ? SupervisorPublished.N : SupervisorPublished.Y;
	const final = res.publish ?? origin;
	if (final === origin) {
		ElMessage.warning('操作失败' + (res.fail_msg ? `：${res.fail_msg}` : ''));
		return;
	}

	tableData.value[index].published = final;

	published === SupervisorPublished.Y ? ElMessage.success('发布成功') : ElMessage.info('已取消发布');
};
//#endregion

//#region ====================== 更新发布状态 ======================
// useUpdateData({
// 	event: 'supervisor.publish',
// 	updateFun({ id, published }) {
// 		updatePublishedById(id, published);
// 	},
// });
//#endregion
//#region ====================== 数据源配置弹窗 ======================
const dataSourceConfigDlgIsShow = ref(false);
const dataSourceConfigDlgMapRow = ref(null);
const openDataSourceConfigDlg = (row?: any) => {
	dataSourceConfigDlgMapRow.value = row;
	dataSourceConfigDlgIsShow.value = true;
};
//#endregion
onMounted(() => {
	getTableData();
});
</script>
<style scoped lang="scss"></style>
